from django import template
from django.utils.html import format_html

import iconic

register = template.Library()


@register.simple_tag
def iconic_icon(name, *, size=24, **kwargs):
    return _iconic(name, size, **kwargs)


def _iconic(name, size, **kwargs):
    svg = iconic.load_icon(name)
    start = '<svg width="{}" height="{}" '
    if kwargs:
        start += " ".join(f'{name.replace("_", "-")}="{{}}"' for name in kwargs)
        start += " "

    svg = svg.replace('<svg width="24" height="24" ', start, 1)

    # simple_tag's parsing loads passed strings as safe, but they aren't
    # Cast the SafeString's back to normal strings the only way possible, by
    # concatenating the empty string.
    unsafe_values = [v + "" for v in kwargs.values()]

    return format_html(svg, size, size, *unsafe_values)



from markupsafe import Markup

import iconic


def iconic_icon(name, *, size=24, **kwargs):
    return _iconic(name, size, **kwargs)


def _iconic(name, size, **kwargs):
    svg = iconic.load_icon(name)
    start = '<svg width="{}" height="{}" '
    if kwargs:
        start += " ".join(f'{name.replace("_", "-")}="{{}}"' for name in kwargs)
        start += " "

    svg = Markup(svg.replace('<svg width="24" height="24" ', start, 1))
    return svg.format(size, size, *kwargs.values())



import functools
import sys
from contextlib import closing
from zipfile import ZipFile

if sys.version_info >= (3, 7):
    from importlib.resources import open_binary
else:
    from importlib_resources import open_binary


class IconDoesNotExist(Exception):
    pass


@functools.lru_cache(maxsize=128)
def load_icon(name):
    zip_data = open_binary("iconic", "iconicicons.zip")
    with closing(zip_data), ZipFile(zip_data, "r") as zip_file:
        try:
            svg_bytes = zip_file.read(f"{name}.svg")
        except KeyError:
            raise IconDoesNotExist(f"The icon {name!r} does not exist.")

        # Inline SVG's don't need xmlns
        return svg_bytes.decode().replace(' xmlns="http://www.w3.org/2000/svg"', "", 1)
